%define distname %{name}-%{version}

# See:
# https://bugs.freedesktop.org/show_bug.cgi?id=91643
%bcond_with egl

Name:		mesa-demos
Version: 	8.3.0
Release: 	%mkrel 1
Summary:	Demos for Mesa (OpenGL compatible 3D lib)
Group:		Graphics/Utilities

# (tv) BR probably need to be shrinked:
BuildRequires:	tcl
BuildRequires:	texinfo
BuildRequires:	libxfixes-devel		>= 4.0.3
BuildRequires:	libxt-devel		>= 1.0.5
BuildRequires:	libxmu-devel		>= 1.0.3
BuildRequires:	libx11-devel		>= 1.3.3
BuildRequires:	libxdamage-devel	>= 1.1.1
BuildRequires:	libexpat-devel		>= 2.0.1
BuildRequires:	gccmakedep
BuildRequires:	x11-proto-devel		>= 7.3
BuildRequires:	libdrm-devel		>= 2.4.19-3

BuildRequires:	libxext-devel		>= 1.1.1
BuildRequires:	libxxf86vm-devel	>= 1.1.0
BuildRequires:	libxi-devel		>= 1.3

BuildRequires:	libglew-devel

%if %with egl
BuildRequires:	mesaegl-devel
BuildRequires:	mesaglesv1-devel
BuildRequires:	mesaglesv2-devel
%endif
BuildRequires:	gbm-devel

# (tv) for glinfo:
BuildRequires:	freeglut-devel

URL:		http://www.mesa3d.org
# git clone git://anongit.freedesktop.org/mesa/demos
# NAME=mesa-demos; DATE=$(git show -s --pretty=%ai | awk '{ gsub("-", "", $1); print $1 }'); DISTNAME=$NAME-$DATE ; git archive --format=tar.gz --prefix=$DISTNAME/ HEAD > $DISTNAME.tar.gz
Source0:	ftp://ftp.freedesktop.org/pub/mesa/demos/%version/%{distname}.tar.bz2
Source4:	Mesa-icons.tar.bz2

License:	MIT

Requires:	glxinfo = %{version}

%package -n	glxinfo
Summary:	Commandline GLX information tool
Group:		Graphics/Utilities
Conflicts:	mesa-demos < 7.7-4

%description
Mesa is an OpenGL 2.1 compatible 3D graphics library.

This package contains some demo programs for the Mesa library.

%description -n	glxinfo
Mesa is an OpenGL 2.1 compatible 3D graphics library.

This package contains the glinfo & glxinfo GLX information utility.

%prep
%setup -q -n %{distname}
%autopatch -p1
perl -pi -e "s,\"([^/].+?)\.(vert|geom|frag)\",\"%{_datadir}/%{name}/\$1.\$2\",g" src/*/*.c

%build
LIB_DIR=%{_lib}
INCLUDE_DIR=$RPM_BUILD_ROOT%{_includedir}
export LIB_DIR INCLUDE_DIR DRI_DRIVER_DIR

autoreconf -fvi
%configure2_5x --with-system-data-files \
%if %without egl
    --disable-egl \
%endif


%make

%install
%makeinstall_std

# (fg) So that demos at least work :)
cp -a src/*/*.{frag,vert,geom} %{buildroot}/%{_datadir}/%{name}

# (tv) fix conflict with bitmap:
mv %{buildroot}/%{_bindir}/bitmap{,-gl}

%if %with egl
# (blino) install some egl test apps as well
pushd src/egl/opengl
for p in eglgears_screen eglgears_x11 eglinfo eglkms egltri_screen egltri_x11 peglgears xeglgears xeglthreads; do
    install -m755 $p %{buildroot}%{_bindir}
done
popd
%endif

# icons for three demos examples [we lack a frontend
# to launch the demos obviously]
install -m 755 -d $RPM_BUILD_ROOT%{_miconsdir}
install -m 755 -d $RPM_BUILD_ROOT%{_iconsdir}
install -m 755 -d $RPM_BUILD_ROOT%{_liconsdir}
tar jxvf %{SOURCE4} -C $RPM_BUILD_ROOT%{_iconsdir}

%files
%{_bindir}/*
%exclude %{_bindir}/glxinfo
%exclude %{_bindir}/glinfo
%dir %{_datadir}/%{name}
%{_datadir}/%{name}/*
%{_miconsdir}/*demos*.png
%{_iconsdir}/*demos*.png
%{_liconsdir}/*demos*.png

%files -n glxinfo
%{_bindir}/glxinfo
%{_bindir}/glinfo


%changelog
* Thu Dec 10 2015 tv <tv> 8.3.0-1.mga6
+ Revision: 909341
- new release

* Thu Sep 10 2015 shlomif <shlomif> 8.2.0-7.mga6
+ Revision: 875386
- Made the handling of no-EGL better (so can be built outside the BS).

* Mon Aug 24 2015 sander85 <sander85> 8.2.0-6.mga6
+ Revision: 869129
- Rebuild for glew 1.13.0

* Fri Aug 14 2015 tv <tv> 8.2.0-5.mga6
+ Revision: 864684
- disable EGL thus fixing build

  + akien <akien>
    - Rebuild for GLEW 1.12

* Wed Oct 15 2014 umeabot <umeabot> 8.2.0-4.mga5
+ Revision: 751132
- Second Mageia 5 Mass Rebuild

* Tue Sep 16 2014 umeabot <umeabot> 8.2.0-3.mga5
+ Revision: 682363
- Mageia 5 Mass Rebuild

* Mon Sep 01 2014 luigiwalser <luigiwalser> 8.2.0-2.mga5
+ Revision: 670273
- rebuild for glew

* Sun Jul 06 2014 tv <tv> 8.2.0-1.mga5
+ Revision: 644071
- drop merged patch
- new release

* Sun Jun 22 2014 akien <akien> 8.1.0-4.mga5
+ Revision: 638635
- Add upstream patch to fix build with gcc 4.9

* Sat Oct 19 2013 umeabot <umeabot> 8.1.0-3.mga4
+ Revision: 530460
- Mageia 4 Mass Rebuild

* Wed Jul 24 2013 sander85 <sander85> 8.1.0-2.mga4
+ Revision: 457716
- Rebuild for new glew

* Sun Feb 24 2013 tmb <tmb> 8.1.0-1.mga3
+ Revision: 400229
- update to 8.1.0 (mga #9170)

* Thu Jan 24 2013 fwang <fwang> 8.0.1-8.20120910.2.mga3
+ Revision: 391847
- update rpm group

* Mon Sep 10 2012 blino <blino> 8.0.1-8.20120910.1.mga3
+ Revision: 292087
- install some egl test apps
- update to snapshot from 20120910
- drop merged patch

* Sun Aug 19 2012 pterjan <pterjan> 8.0.1-8.20120722.1.mga3
+ Revision: 282391
- Rebuild for new glew

* Tue Aug 07 2012 blino <blino> 8.0.1-7.20120722.1.mga3
+ Revision: 279898
- eglkms: adapt to gbm stride API change (reported as fdo #53226)
- update to snapshot from 20120722

* Mon Apr 23 2012 blino <blino> 8.0.1-7.20120227.2.mga2
+ Revision: 232785
- really use system data files and add back hacks to use/install .frag/.vert/.geom files

* Fri Mar 02 2012 blino <blino> 8.0.1-7.20120227.1.mga2
+ Revision: 216616
- use git snapshot (20120227)
- enable egl and gles demos
- remove manual data install, now done by autotools
- remove clear binary renaming, it does not exist anymore
- remove patch0 (literal string), merged upstream

* Mon Oct 03 2011 fwang <fwang> 8.0.1-7.mga2
+ Revision: 151182
- rebuild for new glew

* Thu Sep 22 2011 pterjan <pterjan> 8.0.1-6.mga2
+ Revision: 146834
- Swtich to freeglut (#2541)

* Mon Jan 17 2011 pterjan <pterjan> 8.0.1-5.mga1
+ Revision: 20972
- Drop old stuff
- imported package mesa-demos

